//#define XERR
#include "tumorinfo.ih"

void TumorInfo::refresh(bool spread)
{
    if (not spread)
        return;

    d_incidence.refresh();
    d_growth.refresh();
    d_survival.refresh();
}
